@@ -1,5 +1,5 @@
 import inspect
-from src.xayah.test_result import TestResult
+from .test_result import TestResult
 import time
 
 
